import {client, navigateTo} from "../../index.js";
import AbstractAuthenticatedView from "../abstracts/AbstractAuthenticatedView.js";

export default class extends AbstractAuthenticatedView
{
    constructor(params)
	{
        super(params, "Tournament");
		this.id = params.id;
    }

	async external_search()
	{
		let state = document.getElementById("state-select").value;
		this.tournaments = await client.tournaments.search(state);
		//console.log(this.tournaments);
	}

	internal_search()
	{

		this.display_tournaments = [];
		this.tournaments.forEach(tournament => {
				this.display_tournaments.push(tournament);
		});
	}

	display_result()
	{
		const tournaments_list = document.getElementById("tournaments-list");

		const new_children = [];
		
		console.log(this.display_tournaments);
		this.display_tournaments.forEach(tournament => {

			let tr = document.createElement("tr");

			// name	
			let td = document.createElement("td");
			let button_tournament = document.createElement("a");
			button_tournament.innerText = tournament.name;
			button_tournament.onclick = async () => {
				await navigateTo(String(tournament.id));
			}
			button_tournament.href = "";
			td.appendChild(button_tournament);
			tr.appendChild(td);

			// state
			td = document.createElement("td");
			td.innerText = tournament.state;
			tr.appendChild(td);

			// nb_participants
			td = document.createElement("td");
			td.innerText = tournament.nb_participants;
			tr.appendChild(td);

			new_children.push(tr);
		});
		tournaments_list.replaceChildren(...new_children);
	}

	async update_query()
	{
		this.internal_search();
		this.display_result();
	}

	async update_search()
	{
		await this.external_search();
		this.update_query();
	}

	async postInit()
	{
		await this.update_search();
		document.getElementById("state-select").onchange = this.update_search.bind(this);
	}

	async getHtml()
	{
		return `
			<select id="state-select">
				<option value="waiting">Waiting</option>
				<option value="started">Started</option>
				<option value="finished">Finished</option>
				<option value="all">All</option>
			</select>
			<table>
				<thead>
					<td>Name</td>
					<td>Status</td>
					<td>Max numbers of participants</td>
				</thead>
				<tbody id="tournaments-list">
				</tbody>
			</table>
		`;
	}
}
